# Metagrid


## Description

Metagrid is a Python library for creating simple 2D grid games.

A grid cell can be:

- Plain colored
- An image
- A character

## Installation

You can install Metagrid using pip:

```shell
pip install metagrid